require("__tenebris__.util")

local meld = require("meld")

local types_to_convert = {
    "inserter",
    "assembling%-machine",
    "furnace",
    "recycler",
    "mining%-drill",
    "agricultural%-tower",
    "oil%-refinery",
    "chemical%-plant",
    "biochamber"
}

local unique_subgroups = {}

local all_items = table.deepcopy(data.raw.item)

for _, machine in pairs(all_items) do
    if not contains_any(machine.name, types_to_convert) then goto skip end

    unique_subgroups[machine.subgroup] = true

    data:extend({
        meld(table.deepcopy(machine), {
            name = "bioluminescent-" .. machine.name,
            icon = meld.delete(),
            subgroup = "bioluminescent-" .. machine.subgroup,
            order = "z[bioluminescent-" .. machine.name .. "]",
            place_result = "bioluminescent-" .. machine.name,
            icons = {
                {
                    icon = "__tenebris__/graphics/icons/item-glow.png",
                    icon_size = 64,
                },
                {
                    icon = machine.icon,
                    icon_size = 64,
                    mipmap_count = 4
                }
            },
            pictures = {
                layers = {
                    {
                        filename = machine.icon,
                        scale = 0.5,
                        size = 64,
                        mipmap_count = 4
                    },
                    {
                        filename = "__tenebris__/graphics/icons/item-glow.png",
                        size = 64,
                        draw_as_light = true,
                    },
                }
            }
        }),
        {
            type = "recipe",
            name = "bioluminescent-" .. machine.name,
            localised_name = { "recipe-name.bioinfuse-item", { "entity-name." .. machine.name } },
            order = "x",
            category = "crafting",
            ingredients = {
                { type = "item", name = machine.name,             amount = 1 },
                { type = "item", name = "bioluminescent-crystal", amount = 4 }
            },
            results = { { type = "item", name = "bioluminescent-" .. machine.name, amount = 1 } },
            energy_required = 10.0,
            allow_productivity = false,
            surface_conditions = {
                {
                    property = "pressure",
                    min = 3000,
                    max = 3000
                }
            }
        }
    })

    ::skip::
end

local function create_bioluminescent_entity(entities, exclude)
    local result = {}
    for _, entity in pairs(entities) do
        local name = "bioluminescent-" .. entity.name
        if data.raw["item"][name] then
            result[name] =
                meld(table.deepcopy(entity), {
                    name = name,
                    -- probably bad idea but fuck it
                    rotation_speed = (entity.rotation_speed or 0) * 1.5,
                    crafting_speed = (entity.crafting_speed or 0) * 1.5,
                    localised_name = { "entity-name.bioluminescent-entity", { "entity-name." .. entity.name } },
                    energy_source = { type = "void" },
                    integration_patch_render_layer = "light-effect",
                    integration_patch = {
                        filename = "__tenebris__/graphics/icons/item-glow.png",
                        size = 64,
                        scale = 4,
                        draw_as_light = true,
                    },
                    minable = { mining_time = 0.2, result = name },
                    surface_conditions = {
                        {
                            property = "pressure",
                            min = 3000,
                            max = 3000
                        }
                    }
                })
        end
    end

    return result
end

local biolum_types = flatten {
    create_bioluminescent_entity(table.deepcopy(data.raw["inserter"])),
    create_bioluminescent_entity(table.deepcopy(data.raw["assembling-machine"])),
    create_bioluminescent_entity(table.deepcopy(data.raw["furnace"])),
    create_bioluminescent_entity(table.deepcopy(data.raw["mining-drill"])),
    create_bioluminescent_entity(table.deepcopy(data.raw["agricultural-tower"])),
}

data:extend(biolum_types)

for subgroup, _ in pairs(unique_subgroups) do
    local old = data.raw["item-subgroup"][subgroup]

    data:extend({
        {
            type = "item-subgroup",
            name = "bioluminescent-" .. subgroup,
            group = "bioluminescent",
            order = "z[bioluminescent-" .. subgroup .. "]"
        }
    })
end
